#[non_exhaustive]pub struct StartResourceStateUpdateInput {
pub resource_arn: Option<String>,
pub state: Option<ResourceState>,
pub execution_role: Option<String>,
pub include_resources: Option<ResourceStateUpdateIncludeResources>,
pub exclusion_rules: Option<ResourceStateUpdateExclusionRules>,
pub update_at: Option<DateTime>,
pub client_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.resource_arn: Option<String>The Amazon Resource Name (ARN) of the image build version to update. The image must be in one of these terminal states: AVAILABLE, DEPRECATED, DISABLED, FAILED, or CANCELLED. Images with FAILED or CANCELLED status can transition only to DELETED.
state: Option<ResourceState>Specifies the lifecycle action to take for this request. For AMI-based images, valid values are AVAILABLE, DEPRECATED, DISABLED, and DELETED. For container-based images, only DELETED is supported.
execution_role: Option<String>The name or Amazon Resource Name (ARN) of the IAM role that’s used to update image state.
include_resources: Option<ResourceStateUpdateIncludeResources>Specifies which image resources to include in the state update. When specified, the lifecycle action applies to underlying resources. These resources include AMIs, snapshots, and containers in addition to the Image Builder image resource. Requires executionRole to also be specified. To delete an image and its underlying resources, you must specify includeResources. To delete only the Image Builder image record without affecting underlying resources, use the DeleteImage API instead.
exclusion_rules: Option<ResourceStateUpdateExclusionRules>Skip action on the image resource and associated resources if specified exclusion rules are met.
update_at: Option<DateTime>Specifies the timestamp when the state transition takes effect. Use this parameter only when the target status is DEPRECATED. The value must be a future time.
client_token: Option<String>Unique, case-sensitive identifier you provide to ensure idempotency of the request. For more information, see Ensuring idempotency in the Amazon EC2 API Reference.
Implementations
Sourceimpl StartResourceStateUpdateInput
impl StartResourceStateUpdateInput
Sourcepub fn resource_arn(&self) -> Option<&str>
pub fn resource_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the image build version to update. The image must be in one of these terminal states: AVAILABLE, DEPRECATED, DISABLED, FAILED, or CANCELLED. Images with FAILED or CANCELLED status can transition only to DELETED.
Sourcepub fn state(&self) -> Option<&ResourceState>
pub fn state(&self) -> Option<&ResourceState>
Specifies the lifecycle action to take for this request. For AMI-based images, valid values are AVAILABLE, DEPRECATED, DISABLED, and DELETED. For container-based images, only DELETED is supported.
Sourcepub fn execution_role(&self) -> Option<&str>
pub fn execution_role(&self) -> Option<&str>
The name or Amazon Resource Name (ARN) of the IAM role that’s used to update image state.
Sourcepub fn include_resources(&self) -> Option<&ResourceStateUpdateIncludeResources>
pub fn include_resources(&self) -> Option<&ResourceStateUpdateIncludeResources>
Specifies which image resources to include in the state update. When specified, the lifecycle action applies to underlying resources. These resources include AMIs, snapshots, and containers in addition to the Image Builder image resource. Requires executionRole to also be specified. To delete an image and its underlying resources, you must specify includeResources. To delete only the Image Builder image record without affecting underlying resources, use the DeleteImage API instead.
Sourcepub fn exclusion_rules(&self) -> Option<&ResourceStateUpdateExclusionRules>
pub fn exclusion_rules(&self) -> Option<&ResourceStateUpdateExclusionRules>
Skip action on the image resource and associated resources if specified exclusion rules are met.
Sourcepub fn update_at(&self) -> Option<&DateTime>
pub fn update_at(&self) -> Option<&DateTime>
Specifies the timestamp when the state transition takes effect. Use this parameter only when the target status is DEPRECATED. The value must be a future time.
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
Unique, case-sensitive identifier you provide to ensure idempotency of the request. For more information, see Ensuring idempotency in the Amazon EC2 API Reference.
Sourceimpl StartResourceStateUpdateInput
impl StartResourceStateUpdateInput
Sourcepub fn builder() -> StartResourceStateUpdateInputBuilder
pub fn builder() -> StartResourceStateUpdateInputBuilder
Creates a new builder-style object to manufacture StartResourceStateUpdateInput.