#[non_exhaustive]pub struct RegisterImageOptionsBuilder { /* private fields */ }Expand description
A builder for RegisterImageOptions.
Implementations
Sourceimpl RegisterImageOptionsBuilder
impl RegisterImageOptionsBuilder
Sourcepub fn secure_boot_enabled(self, input: bool) -> Self
pub fn secure_boot_enabled(self, input: bool) -> Self
Specifies whether Secure Boot is enabled for the output AMI. The default value is true. To disable Secure Boot for custom unsigned drivers, set this value to false.
Sourcepub fn set_secure_boot_enabled(self, input: Option<bool>) -> Self
pub fn set_secure_boot_enabled(self, input: Option<bool>) -> Self
Specifies whether Secure Boot is enabled for the output AMI. The default value is true. To disable Secure Boot for custom unsigned drivers, set this value to false.
Sourcepub fn get_secure_boot_enabled(&self) -> &Option<bool>
pub fn get_secure_boot_enabled(&self) -> &Option<bool>
Specifies whether Secure Boot is enabled for the output AMI. The default value is true. To disable Secure Boot for custom unsigned drivers, set this value to false.
Sourcepub fn uefi_data(self, input: impl Into<String>) -> Self
pub fn uefi_data(self, input: impl Into<String>) -> Self
A Base64-encoded representation of the non-volatile UEFI variable store. You can specify this parameter only when secureBootEnabled is true or unspecified. You can inspect and modify the UEFI data by using the python-uefivars tool on GitHub.
For more information, see UEFI variables for Amazon EC2 instances.
Sourcepub fn set_uefi_data(self, input: Option<String>) -> Self
pub fn set_uefi_data(self, input: Option<String>) -> Self
A Base64-encoded representation of the non-volatile UEFI variable store. You can specify this parameter only when secureBootEnabled is true or unspecified. You can inspect and modify the UEFI data by using the python-uefivars tool on GitHub.
For more information, see UEFI variables for Amazon EC2 instances.
Sourcepub fn get_uefi_data(&self) -> &Option<String>
pub fn get_uefi_data(&self) -> &Option<String>
A Base64-encoded representation of the non-volatile UEFI variable store. You can specify this parameter only when secureBootEnabled is true or unspecified. You can inspect and modify the UEFI data by using the python-uefivars tool on GitHub.
For more information, see UEFI variables for Amazon EC2 instances.
Sourcepub fn build(self) -> RegisterImageOptions
pub fn build(self) -> RegisterImageOptions
Consumes the builder and constructs a RegisterImageOptions.