#[non_exhaustive]pub struct ImageFailureContext {
pub image_status: Option<ImageStatus>,
pub workflow_execution_id: Option<String>,
pub workflow_arn: Option<String>,
pub step_execution_id: Option<String>,
pub failed_step: Option<String>,
pub component_failure: Option<ComponentFailureContext>,
pub distribution_failure: Option<DistributionFailureContext>,
}Expand description
Contains details about the failure when the image creation process fails. Properties appear in the failure context when the related information is available for the failure.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.image_status: Option<ImageStatus>The status that the image had when the failure occurred. This indicates the stage of the image creation process where the image failed, for example BUILDING or DISTRIBUTING.
workflow_execution_id: Option<String>The unique identifier of the workflow execution that was running when the image failed.
workflow_arn: Option<String>The Amazon Resource Name (ARN) of the workflow build version that was running when the image failed.
step_execution_id: Option<String>The unique identifier of the workflow step execution that failed.
failed_step: Option<String>The name of the workflow step that failed, as it appears in the workflow document.
component_failure: Option<ComponentFailureContext>The details about the component that failed, if the failure occurred while a component was running.
distribution_failure: Option<DistributionFailureContext>The details about the distribution failure, if the failure occurred while Image Builder distributed or configured the image.
Implementations
Sourceimpl ImageFailureContext
impl ImageFailureContext
Sourcepub fn image_status(&self) -> Option<&ImageStatus>
pub fn image_status(&self) -> Option<&ImageStatus>
The status that the image had when the failure occurred. This indicates the stage of the image creation process where the image failed, for example BUILDING or DISTRIBUTING.
Sourcepub fn workflow_execution_id(&self) -> Option<&str>
pub fn workflow_execution_id(&self) -> Option<&str>
The unique identifier of the workflow execution that was running when the image failed.
Sourcepub fn workflow_arn(&self) -> Option<&str>
pub fn workflow_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the workflow build version that was running when the image failed.
Sourcepub fn step_execution_id(&self) -> Option<&str>
pub fn step_execution_id(&self) -> Option<&str>
The unique identifier of the workflow step execution that failed.
Sourcepub fn failed_step(&self) -> Option<&str>
pub fn failed_step(&self) -> Option<&str>
The name of the workflow step that failed, as it appears in the workflow document.
Sourcepub fn component_failure(&self) -> Option<&ComponentFailureContext>
pub fn component_failure(&self) -> Option<&ComponentFailureContext>
The details about the component that failed, if the failure occurred while a component was running.
Sourcepub fn distribution_failure(&self) -> Option<&DistributionFailureContext>
pub fn distribution_failure(&self) -> Option<&DistributionFailureContext>
The details about the distribution failure, if the failure occurred while Image Builder distributed or configured the image.
Sourceimpl ImageFailureContext
impl ImageFailureContext
Sourcepub fn builder() -> ImageFailureContextBuilder
pub fn builder() -> ImageFailureContextBuilder
Creates a new builder-style object to manufacture ImageFailureContext.