#[non_exhaustive]pub struct RegionFailure {
pub region: Option<String>,
pub status: Option<RegionFailureStatus>,
pub image_configuration_step: Option<ImageConfigurationStep>,
pub error_message: Option<String>,
pub target_account_id: Option<String>,
}Expand description
Contains details about a distribution or image configuration failure for a single Region.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.region: Option<String>The Region where the failure occurred.
status: Option<RegionFailureStatus>The failure status for the Region. Indicates whether the process failed, was canceled, or timed out.
image_configuration_step: Option<ImageConfigurationStep>The image configuration step where the failure occurred. Image Builder sets this property when the failure happened during post-distribution configuration, such as launch template updates or virtual machine (VM) export. This property doesn't appear for failures that occurred while Image Builder copied the image to the Region.
error_message: Option<String>The error message for the failure in the Region.
target_account_id: Option<String>The account ID of the account that the image was distributed to in the Region.
Implementations
Sourceimpl RegionFailure
impl RegionFailure
Sourcepub fn status(&self) -> Option<&RegionFailureStatus>
pub fn status(&self) -> Option<&RegionFailureStatus>
The failure status for the Region. Indicates whether the process failed, was canceled, or timed out.
Sourcepub fn image_configuration_step(&self) -> Option<&ImageConfigurationStep>
pub fn image_configuration_step(&self) -> Option<&ImageConfigurationStep>
The image configuration step where the failure occurred. Image Builder sets this property when the failure happened during post-distribution configuration, such as launch template updates or virtual machine (VM) export. This property doesn't appear for failures that occurred while Image Builder copied the image to the Region.
Sourcepub fn error_message(&self) -> Option<&str>
pub fn error_message(&self) -> Option<&str>
The error message for the failure in the Region.
Sourcepub fn target_account_id(&self) -> Option<&str>
pub fn target_account_id(&self) -> Option<&str>
The account ID of the account that the image was distributed to in the Region.
Sourceimpl RegionFailure
impl RegionFailure
Sourcepub fn builder() -> RegionFailureBuilder
pub fn builder() -> RegionFailureBuilder
Creates a new builder-style object to manufacture RegionFailure.