#[non_exhaustive]pub struct RegisterImageOptions {
pub secure_boot_enabled: Option<bool>,
pub uefi_data: Option<String>,
}Expand description
Controls Secure Boot and UEFI data settings for the resulting image during ISO imports. For more information, see UEFI Secure Boot for Amazon EC2 instances in the Amazon EC2 User Guide .
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.secure_boot_enabled: Option<bool>Specifies whether Secure Boot is enabled for the output AMI. The default value is true. To disable Secure Boot for custom unsigned drivers, set this value to false.
uefi_data: Option<String>A Base64-encoded representation of the non-volatile UEFI variable store. You can specify this parameter only when secureBootEnabled is true or unspecified. You can inspect and modify the UEFI data by using the python-uefivars tool on GitHub.
For more information, see UEFI variables for Amazon EC2 instances.
Implementations
Sourceimpl RegisterImageOptions
impl RegisterImageOptions
Sourcepub fn secure_boot_enabled(&self) -> Option<bool>
pub fn secure_boot_enabled(&self) -> Option<bool>
Specifies whether Secure Boot is enabled for the output AMI. The default value is true. To disable Secure Boot for custom unsigned drivers, set this value to false.
Sourcepub fn uefi_data(&self) -> Option<&str>
pub fn uefi_data(&self) -> Option<&str>
A Base64-encoded representation of the non-volatile UEFI variable store. You can specify this parameter only when secureBootEnabled is true or unspecified. You can inspect and modify the UEFI data by using the python-uefivars tool on GitHub.
For more information, see UEFI variables for Amazon EC2 instances.
Sourceimpl RegisterImageOptions
impl RegisterImageOptions
Sourcepub fn builder() -> RegisterImageOptionsBuilder
pub fn builder() -> RegisterImageOptionsBuilder
Creates a new builder-style object to manufacture RegisterImageOptions.